@@ -2,22 +2,25 @@ from functools import wraps
 from flask import Flask
 import pytest
 
-from tests.test_utils.db import clean, db
-from tests.test_utils.setup import setup
+from api.database import create, db, delete
+from api.setup import setup
 
 
 @pytest.fixture(scope='session')
 def app():
     FLASK_APP = Flask(__name__)
     setup(FLASK_APP)
+    try:
+        create()
+    except Exception:
+        pass
     return FLASK_APP
 
 
-def with_clean(f):
+def with_delete(f):
     @wraps(f)
     def decorated_function(*args, **kwargs):
         db.session.rollback()
-        clean()
+        delete()
         return f(*args, **kwargs)
-
     return decorated_function
